Python: module excerpts.os

excerpts.os | index /home/qwer/git/cyclops/fvafrcu/excerpts/excerpts/os.py

`## @file
# operating system functions`

Modules
`` |  |
excerpts.main | os | subprocess |

Functions
`` |  | is_tool(name) `## Test if a Program is Installed # # Will raise an error if the programm is not found. # @param name The name of the program to be tested for. # @return True if the Program is installed.` pandoc(file_name, compile_latex=False, formats='tex') `## Run Pandoc on a File # # @param file_name The file from which the lines are to be extracted. # @param formats The pandoc output formats to be used. # @param compile_latex Compile the LaTeX file? # @return True if parsing was successful.`

Data
`` |  | print_function = _Feature((2, 6, 0, 'alpha', 2), (3, 0, 0, 'alpha', 0), 65536)